==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_pages.php <==
<?php
class Pages extends Admin {
	public function __construct() {
		$this->pagePos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function user_params($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function totalItems($table) {
		$query = "SELECT COUNT(ID) AS NUM FROM ".$table;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result['NUM'];	
	}
	public function update_pages() {
		$values = $_POST;
		foreach($values as $k=>$v) {
			if ( preg_match("/\_/",$k) ) {
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value) {
			$query = 0;
			if ($value['oldname'] != $value['name']) {
				$query = "UPDATE ".PAGES." SET NAME = '".$value['name']."' WHERE ID = ".$id;
				$query = $this->q($query);
			}
			if (isset($value['delete'])) {
				$query = "DELETE FROM ".PAGES." WHERE ID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".USERPAGES." WHERE PAGEID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".ARTICLES." WHERE PAGEID = ".$id;
				$query = $this->q($query);
			}
			if (isset($value['hide']) && $value['oldhide'] == 0) {
				$query = "UPDATE ".PAGES." SET HIDE = 1 WHERE ID = ".$id;
				$query = $this->q($query);
			} else if (!isset($value['hide']) && $value['oldhide'] == 1) {
				$query = "UPDATE ".PAGES." SET HIDE = 0 WHERE ID = ".$id;
				$query = $this->q($query);
				$query = "UPDATE ".ARTICLES." SET HIDE = 0 WHERE PAGEID = ".$id;
				$query = $this->q($query);
			}
		}
		$result = "some values have been modified !";;
		return $result;
	}
	public function list_pages($pgPos=0) {
		if ($pgPos) $pgPos = ($pgPos - 1) * ADMINITEMSBYPAGE;
		if (isset($_POST['search'])) {
			$queryLevel1 = 	"SELECT ".PAGES.".*,".USERS.".USERNAME FROM ".PAGES.",".USERS." WHERE ".
							USERS.".ID = ".PAGES.".USERID AND ".
							"MATCH(".PAGES.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
							USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
							USERPAGES.".PAGEID = ".PAGES.".ID AND ".
							"MATCH(".PAGES.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} else {
			$queryLevel1 = 	"SELECT ".PAGES.".*,".USERS.".USERNAME FROM ".PAGES.",".USERS." WHERE ".
							USERS.".ID = ".PAGES.".USERID ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
							USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
							USERPAGES.".PAGEID = ".PAGES.".ID ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		}
		$queryLevel3 = $queryLevel2;
		
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		
		$searchForm = $this->h->p($this->h->input("submit","",$this->tr->w("search name"))." ".$this->h->input("text","search",""));
		$searchForm = $this->h->form($searchForm,"search","post","admin.php?action=pages");
		
		$catListSubmit = $this->h->p($this->h->input("submit","",$this->tr->w("update all")));
		
		$catList = $this->h->h3($this->tr->w("pages list"));
		$catList .= $this->h->input("hidden","update",1);
		$i = 1;
		while ( $line = mysql_fetch_assoc($query) ) {
			$sandboxParams = "";
			if ($line['NAME'] == "SANDBOX") {
				$sandboxParams = "readonly";
			}
			$content = $this->h->input("hidden","id",$line['ID']);
			$content .= $this->h->ahref("admin.php?action=modify_page&amp;cat=".$line['ID'],$this->tr->w("modify"))." ";
			$content .= $this->h->ahref("index.php?cat=".$line['ID'],$this->tr->w("view"),"target=_blank")." ";
			$params =  ($line['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->tr->w("hide").$this->h->input("checkbox","hide_".$line['ID'],"on",$params)." ";
			$content .= $this->h->input("hidden","oldhide_".$line['ID'],$line['HIDE']);
			$content .= $this->tr->ws("title").$this->h->input("text","name_".$line['ID'],$line['NAME'],$sandboxParams." size=35")." ";
			$content .= $this->h->input("hidden","oldname_".$line['ID'],$line['NAME']);
			$content .= ($line['NAME'] != "SANDBOX")?"delete".$this->h->input("checkbox","delete_".$line['ID'],"on")." ":$this->h->span($this->tr->w("protected"),"style=\"color:red\"");
			($_SESSION['level'] == 1)?$content .= $this->tr->w("{by-").$line['USERNAME']."}":null;
			$catList .= $this->h->p($content);
		}
		$nextPages = $this->h->p($this->next_pages());
		$catList = $catListSubmit.$catList.$nextPages.$catListSubmit;
		$result = $searchForm.$this->h->form($catList,"pages","post","admin.php?action=pages&amp;pg=".$this->pagePos);
		return $result;
	}
	public function list_pages_select($catId,$name) {
		$query = "SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES;
		$query = $this->q($query);
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $catId) {
				$elements[$line['NAME']] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$result = $this->h->select($elements,$name,$catId);
		return $result;
	}
	public function next_pages(){
		$queryLevel1 = 	"SELECT COUNT(ID) AS NUM FROM ".PAGES;
		$queryLevel2 = 	"SELECT COUNT(".PAGES.".ID) AS NUM FROM ".PAGES.",".USERS." WHERE ".PAGES.".USERID = ".USERS.".ID AND ".USERS.".USERLEVEL > 1 ";
		$queryLevel3 = 	"SELECT COUNT(ID) AS NUM FROM ".PAGES." WHERE USERID = ".$_SESSION['userid'];
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		$line = mysql_fetch_assoc($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=pages");
		$result = $this->h->p($pagesNumbers->numbers());
		return $result;
	}
}
?>

==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin_pages.php <==
<?php
class Pages extends Admin {
	public function __construct() {
		$this->pagePos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function user_params($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function totalItems($table) {
		$query = "SELECT COUNT(ID) AS NUM FROM ".$table;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result['NUM'];	
	}
	public function update_pages() {
		$values = $_POST;
		foreach($values as $k=>$v) {
			if ( preg_match("/\_/",$k) ) {
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value) {
			$query = 0;
			if ($value['oldname'] != $value['name']) {
				$query = "UPDATE ".PAGES." SET NAME = '".$value['name']."' WHERE ID = ".$id;
				$query = $this->q($query);
			}
			if (isset($value['delete'])) {
				$query = "DELETE FROM ".PAGES." WHERE ID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".USERPAGES." WHERE PAGEID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".ARTICLES." WHERE PAGEID = ".$id;
				$query = $this->q($query);
                $query = "UPDATE ".PAGES." SET PARENTID = 0 WHERE PARENTID = ".$id;
				$query = $this->q($query);
                
			}
			if (isset($value['hide']) && $value['oldhide'] == 0) {
				$query = "UPDATE ".PAGES." SET HIDE = 1 WHERE ID = ".$id;
				$query = $this->q($query);
			} else if (!isset($value['hide']) && $value['oldhide'] == 1) {
				$query = "UPDATE ".PAGES." SET HIDE = 0 WHERE ID = ".$id;
				$query = $this->q($query);
				$query = "UPDATE ".ARTICLES." SET HIDE = 0 WHERE PAGEID = ".$id;
				$query = $this->q($query);
			}
		}
		$result = "some values have been modified !";
		return $result;
	}
	public function list_pages($pgPos=0) {
		if ($pgPos) $pgPos = ($pgPos - 1) * ADMINITEMSBYPAGE;
        
        if (isset($_GET['ownerFilter'])){
            $_SESSION['admin_pages_filter'] = $_GET['ownerFilter'];
        }
        if (isset($_POST['reset'])){
            $_SESSION['admin_pages_filter'] = "";
        }
        $owners = array();
		$query = $this->q("SELECT ID,USERNAME FROM ".USERS);
		while ( $line = @mysql_fetch_assoc($query) ) {
			$owners[$line['USERNAME']] = $line['ID'];
		}
		if (isset($_POST['search'])) {
			$queryLevel1 = 	"SELECT ".PAGES.".*,".USERS.".USERNAME FROM ".PAGES.",".USERS." WHERE ".
							USERS.".ID = ".PAGES.".USERID AND ".
							"MATCH(".PAGES.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
							USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
							USERPAGES.".PAGEID = ".PAGES.".ID AND ".
							"MATCH(".PAGES.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
        } elseif (isset($_SESSION['admin_pages_filter']) && $_SESSION['admin_pages_filter'] != "") {
            $queryLevel1 = 	"SELECT ".PAGES.".*,".USERS.".USERNAME FROM ".PAGES.",".USERS." WHERE ".
                            PAGES.".USERID = ".$_SESSION['admin_pages_filter']." AND ".
							USERS.".ID = ".PAGES.".USERID ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
							USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
							USERPAGES.".PAGEID = ".PAGES.".ID ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} else {
			$queryLevel1 = 	"SELECT ".PAGES.".*,".USERS.".USERNAME FROM ".PAGES.",".USERS." WHERE ".
							USERS.".ID = ".PAGES.".USERID ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
							USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
							USERPAGES.".PAGEID = ".PAGES.".ID ORDER BY ".PAGES.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		}
		$queryLevel3 = $queryLevel2;
		
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		
		$searchForm = $this->h->p($this->h->input("submit","",$this->tr->w("search name"))." ".$this->h->input("text","search",""));
		$searchForm = $this->h->form($searchForm,"search","post","admin.php?action=pages");
        
        $resetForm = $this->h->p($this->h->input("submit","",$this->tr->w("no filters")).$this->h->input("hidden","reset",1));
		$resetForm = $this->h->form($resetForm,"reset","post","admin.php?action=pages");
		
		$catListSubmit = $this->h->p($this->h->input("submit","",$this->tr->w("update all")));
		
		$catList = $this->h->h3($this->tr->w("pages list"));
		$catList .= $this->h->input("hidden","update",1);
		$i = 1;
		while ( $line = mysql_fetch_assoc($query) ) {
			$sandboxParams = "";
			if ($line['NAME'] == "SANDBOX") {
				$sandboxParams = "readonly";
			}
			$content = $this->h->input("hidden","id",$line['ID']);
			$content .= $this->h->ahref("admin.php?action=modify_page&amp;cat=".$line['ID'],$this->tr->w("modify"))." ";
			$content .= $this->h->ahref("index.php?cat=".$line['ID'],$this->tr->w("view"),"target=_blank")." ";
			$params =  ($line['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->tr->w("hide").$this->h->input("checkbox","hide_".$line['ID'],"on",$params)." ";
			$content .= $this->h->input("hidden","oldhide_".$line['ID'],$line['HIDE']);
			$content .= $this->tr->ws("title").$this->h->input("text","name_".$line['ID'],$line['NAME'],$sandboxParams." size=35")." ";
			$content .= $this->h->input("hidden","oldname_".$line['ID'],$line['NAME']);
			$content .= ($line['NAME'] != "SANDBOX")?"delete".$this->h->input("checkbox","delete_".$line['ID'],"on")." ":$this->h->span($this->tr->w("protected"),"style=\"color:red\"");
			($_SESSION['level'] == 1)?$content .= $this->tr->w("by-").$this->h->ahref("admin.php?action=pages&amp;ownerFilter=".$owners[$line['USERNAME']],$line['USERNAME']):null;
            
			$catList .= $this->h->p($content);
		}
		$nextPages = $this->h->p($this->next_pages());
		$catList = $catListSubmit.$catList.$nextPages.$catListSubmit;
		$result = $searchForm.$resetForm.$this->h->form($catList,"pages","post","admin.php?action=pages&amp;pg=".$this->pagePos);
		return $result;
	}
	public function list_pages_select($catId,$name) {
		$query = "SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES;
		$query = $this->q($query);
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $catId) {
				$elements[$line['NAME']] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$result = $this->h->select($elements,$name,$catId);
		return $result;
	}
	public function next_pages(){
		$queryLevel1 = 	"SELECT COUNT(ID) AS NUM FROM ".PAGES;
		$queryLevel2 = 	"SELECT COUNT(".PAGES.".ID) AS NUM FROM ".PAGES.",".USERS." WHERE ".PAGES.".USERID = ".USERS.".ID AND ".USERS.".USERLEVEL > 1 ";
		$queryLevel3 = 	"SELECT COUNT(ID) AS NUM FROM ".PAGES." WHERE USERID = ".$_SESSION['userid'];
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		$line = mysql_fetch_assoc($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=pages");
		$result = $this->h->p($pagesNumbers->numbers());
		return $result;
	}
}
?>
